@@ -8,12 +8,12 @@ package Math::KalmanFilter;
 #
 # This file is part of Math-KalmanFilter
 #
-# This software is copyright (c) 2013 by Shantanu Bhadoria.
+# This software is copyright (c) 2016 by Shantanu Bhadoria.
 #
 # This is free software; you can redistribute it and/or modify it under
 # the same terms as the Perl 5 programming language system itself.
 #
-our $VERSION = '0.03'; # VERSION
+our $VERSION = '0.05'; # VERSION
 
 # Dependencies
 use 5.010;
@@ -109,7 +109,7 @@ Math::KalmanFilter - Kalman Filter(also known as Linear Quadratic Estimation) im
 
 =head1 VERSION
 
-version 0.03
+version 0.05
 
 =head1 SYNOPSIS
 
@@ -222,7 +222,7 @@ Calculate new state based on observed reading from state sensor, delta sensor an
 =head2 Bugs / Feature Requests
 
 Please report any bugs or feature requests through github at 
-L<https://github.com/shantanubhadoria/math-kalmanfilter/issues>.
+L<https://github.com/shantanubhadoria/perl-math-kalmanfilter/issues>.
 You will be notified automatically of any progress on your issue.
 
 =head2 Source Code
@@ -230,9 +230,9 @@ You will be notified automatically of any progress on your issue.
 This is open source software.  The code repository is available for
 public review and contribution under the terms of the license.
 
-L<https://github.com/shantanubhadoria/math-kalmanfilter>
+L<https://github.com/shantanubhadoria/perl-math-kalmanfilter>
 
-  git clone git://github.com/shantanubhadoria/math-kalmanfilter.git
+  git clone git://github.com/shantanubhadoria/perl-math-kalmanfilter.git
 
 =head1 AUTHOR
 
@@ -240,6 +240,8 @@ Shantanu Bhadoria <shantanu at cpan dott org>
 
 =head1 CONTRIBUTORS
 
+=for stopwords Shantanu Bhadoria
+
 =over 4
 
 =item *
@@ -254,7 +256,7 @@ Shantanu Bhadoria <shantanu@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 by Shantanu Bhadoria.
+This software is copyright (c) 2016 by Shantanu Bhadoria.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
